==> songfindercli-0.4.9-py2-none-any.whl: songfinder/data/documentation/README.md <==

# Documentation :

- Pour acceder a la documentation, cliquer sur `Aide`, puis sur `Documentation` dans le menu deroule.
- Elle est egalement disponible sur internet par ce lien :
[http://interne.eglise-pe-franconville.fr/files/techniqueFranconville.html](http://interne.eglise-pe-franconville.fr/files/techniqueFranconville.html)


# Recuperer la base de donnees des chants :

La base de donnees est stocke dans un depot sur internet.
Pour l'avoir sur l'ordinateur, il faut cloner le depot.

- Aller dans `Editer->Parametres Generaux` et cocher `Synchroniser la base de donnees`.
- Confirmer et remplir les trois champs :
	- Chemin : *https://epef@bitbucket.org/epef/data*
	- Utilisateur : *Daniel [Mettre votre prenom]*
	- Mot de passe : *\*\*\* [Mettre le mot de passe]*
- Cliquer sur `Cloner`.
La base de donnees est maintenant sur l'ordinateur.


# Ajouter des accords (prendre pour exemple *Hosanna a l'agneau immole*) :

- Selectionner un chant
- Ajouter une ligne debutant par `\ac` et continuant par les accords devant etre affiches.
- Les accords sont associes aux lignes juste au dessus la ligne contenant les accords.
- Les accords peuvent etre renseigne dans la notation francophone ou anglophone.
- Ne remplir les accords que pour un couplet et un refrain, pas besoin de dupliquer chaque serie d'accords.
- Renseigner la tonalite et le nombre de demis ton de transposition (en haut).


# Envoyer les modifications et recuperer celles des autres contributeurs :

- Dans le menu `Reception/Envoi`, cliquer sur `Envoyer les chants` ou `Recevoir les chants`
- Avant des faire des modifications, il faut verifier que quelqu'un d'autre ne les ai pas deja faite en cliquant sur `Recevoir les chants`.
- Apres avoir fait les modifications, il faut envoyer les chants en cliquant sur `Envoyer les chants`.


# Creer un PDF :

- Faire un double clique sur un chant dans la liste des resultats de recherche (en haut) pour le mettre dans la liste des selections (en bas).
- Repeter cette precedente etape pour tous les chants devant etre dans le PDF
- Dans le menu `Latex` cliquer sur l'entree' `Generer un fichier PDF` (a droite)
- Cocher les options souhaitees
- Enregistrer

==> songfindercli-0.5.8-py2-none-any.whl: songfinder/data/documentation/README.md <==

# Documentation :

- Pour acceder a la documentation, cliquer sur `Aide`, puis sur `Documentation` dans le menu deroule.
- Elle est egalement disponible sur internet par ce lien :
[http://interne.eglise-pe-franconville.fr/files/techniqueFranconville.html](http://interne.eglise-pe-franconville.fr/files/techniqueFranconville.html)


# Recuperer la base de donnees des chants :

La base de donnees est stocke dans un depot sur internet.
Pour l'avoir sur l'ordinateur, il faut cloner le depot.

- Aller dans `Editer->Parametres Generaux` et cocher `Synchroniser la base de donnees`.
- Confirmer et remplir les trois champs :
	- Chemin : *https://epef@bitbucket.org/epef/songfinderdata.git*
	- Utilisateur : *Daniel [Mettre votre prenom]*
	- Mot de passe : *\*\*\* [Mettre le mot de passe]*
- Cliquer sur `Cloner`.
La base de donnees est maintenant sur l'ordinateur.


# Ajouter des accords (prendre pour exemple *Hosanna a l'agneau immole*) :

- Selectionner un chant
- Ajouter une ligne debutant par `\ac` et continuant par les accords devant etre affiches.
- Les accords sont associes aux lignes juste au dessus la ligne contenant les accords.
- Les accords peuvent etre renseigne dans la notation francophone ou anglophone.
- Ne remplir les accords que pour un couplet et un refrain, pas besoin de dupliquer chaque serie d'accords.
- Renseigner la tonalite et le nombre de demis ton de transposition (en haut).


# Envoyer les modifications et recuperer celles des autres contributeurs :

- Dans le menu `Reception/Envoi`, cliquer sur `Envoyer les chants` ou `Recevoir les chants`
- Avant des faire des modifications, il faut verifier que quelqu'un d'autre ne les ai pas deja faite en cliquant sur `Recevoir les chants`.
- Apres avoir fait les modifications, il faut envoyer les chants en cliquant sur `Envoyer les chants`.


# Creer un PDF :

- Faire un double clique sur un chant dans la liste des resultats de recherche (en haut) pour le mettre dans la liste des selections (en bas).
- Repeter cette precedente etape pour tous les chants devant etre dans le PDF
- Dans le menu `Latex` cliquer sur l'entree' `Generer un fichier PDF` (a droite)
- Cocher les options souhaitees
- Enregistrer
